@@ -1,22 +1,9 @@
 /*
-   This file is part of the KDE Baloo project.
- * Copyright (C) 2015  Vishesh Handa <me@vhanda.in>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    This file is part of the KDE Baloo project.
+    SPDX-FileCopyrightText: 2015 Vishesh Handa <me@vhanda.in>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "enginedebug.h"
 #include "postingdb.h"
@@ -132,7 +119,7 @@ QVector< QByteArray > PostingDB::fetchTermsStartingWith(const QByteArray& term)
         qCWarning(ENGINE) << "PostingDB::fetchTermsStartingWith" << mdb_strerror(rc);
         return {};
     }
-    
+
     QVector<QByteArray> terms;
     rc = mdb_cursor_get(cursor, &key, nullptr, MDB_SET_RANGE);
     while (rc == 0) {
@@ -281,6 +268,29 @@ PostingIterator* PostingDB::compIter(const QByteArray& prefix, qlonglong comVal,
     return iter(prefix, validate);
 }
 
+PostingIterator* PostingDB::compIter(const QByteArray& prefix, double comVal, PostingDB::Comparator com)
+{
+    int prefixLen = prefix.length();
+    auto validate = [prefixLen, comVal, com] (const QByteArray& arr) {
+        bool ok = false;
+        auto val = QByteArray::fromRawData(arr.constData() + prefixLen, arr.length() - prefixLen).toDouble(&ok);
+        return ok && ((com == LessEqual && val <= comVal) ||
+                      (com == GreaterEqual && val >= comVal));
+    };
+    return iter(prefix, validate);
+}
+
+PostingIterator* PostingDB::compIter(const QByteArray& prefix, const QByteArray& comVal, PostingDB::Comparator com)
+{
+    int prefixLen = prefix.length();
+    auto validate = [prefixLen, comVal, com] (const QByteArray& arr) {
+        auto val = QByteArray::fromRawData(arr.constData() + prefixLen, arr.length() - prefixLen);
+        return ((com == LessEqual && val <= comVal) ||
+                (com == GreaterEqual && val >= comVal));
+    };
+    return iter(prefix, validate);
+}
+
 QMap<QByteArray, PostingList> PostingDB::toTestMap() const
 {
     MDB_cursor* cursor;
@@ -292,6 +302,9 @@ QMap<QByteArray, PostingList> PostingDB::toTestMap() const
     QMap<QByteArray, PostingList> map;
     while (1) {
         int rc = mdb_cursor_get(cursor, &key, &val, MDB_NEXT);
+        if (rc == MDB_NOTFOUND) {
+            break;
+        }
         if (rc) {
             qCDebug(ENGINE) << "PostingDB::toTestMap" << mdb_strerror(rc);
             break;
